@@ -12,20 +12,20 @@
 #' @exportS3Method predict semtree
 #' @author Caspar van Lissa, Andreas Brandmaier
 #' 
-predict.semtree <- function(object, data, type = "node_id", ...) {
-  
-  if(!hasArg(data)){
-    if(inherits(object$model, "MxModel")){
-      data <- object$model$data$observed
-    } else {
-      ui_stop("Argument 'data' required.")
-    }
-  }
-  result <- switch(type,
-                   "node_id" = { traverse(object, dataset = data)}
-  )
-  
-  if (is.null(result)) ui_stop("Requested type no yet implemented in predict.semtree().")
-  
-  return(result)
-} 
+# predict.semtree <- function(object, data, type = "node_id", ...) {
+#   
+#   if(!hasArg(data)){
+#     if(inherits(object$model, "MxModel")){
+#       data <- object$model$data$observed
+#     } else {
+#       ui_stop("Argument 'data' required.")
+#     }
+#   }
+#   result <- switch(type,
+#                    "node_id" = { traverse(object, dataset = data)}
+#   )
+#   
+#   if (is.null(result)) ui_stop("Requested type no yet implemented in predict.semtree().")
+#   
+#   return(result)
+# } 
