@@ -7,14 +7,14 @@
 #' recursively selecting optimal predictors of these differences from a
 #' potentially large set of predictors.
 #'
-#' Calling \code{semtree} with an \code{\link{OpenMx}} or
+#' Calling \code{semtree} with an \code{\link[OpenMx]{mxModel}} or
 #' \code{\link[lavaan]{lavaan}} model creates a tree that recursively
 #' partitions a dataset such that the partitions maximally differ with respect
 #' to the model-predicted distributions. Each resulting subgroup (represented
 #' as a leaf in the tree) is represented by a SEM with a distinct set of
 #' parameter estimates.
 #'
-#' Predictors (yet unmodeled variables) can take on any form for the splitting
+#' Predictors  can take on any form for the splitting
 #' algorithm to function (categorical, ordered categories, continuous). Care
 #' must be taken in choosing how many predictors to include in analyses because
 #' as the number of categories grows for unordered categorical variables, the
@@ -44,13 +44,13 @@
 #'
 #' @aliases semtree plot.semtree print.semtree summary.semtree toLatex.semtree
 #' nodeFunSemtree
-#' @param model A template model specification from \code{\link{OpenMx}} using
-#' the \code{\link{mxModel}} function (or a \code{\link[lavaan]{lavaan}} model
+#' @param model A template model specification from \pkg{OpenMx} using
+#' the \code{\link[OpenMx]{mxModel}} function or a \pkg{lavaan} model
 #' using the \code{\link[lavaan]{lavaan}} function with option fit=FALSE).
 #' Model must be syntactically correct within the framework chosen, and
 #' converge to a solution.
 #' @param data Data.frame used in the model creation using
-#' \code{\link{mxModel}} or \code{\link[lavaan]{lavaan}} are input here. Order
+#' \code{\link[OpenMx]{mxModel}} or \code{\link[lavaan]{lavaan}} are input here. Order
 #' of modeled variables and predictors is not important when providing a
 #' dataset to \code{semtree}.
 #' @param control \code{\link{semtree}} model specifications from
@@ -85,6 +85,14 @@
 #' @export
 semtree <- function(model, data = NULL, control = NULL, constraints = NULL,
                     predictors = NULL, ...) {
+  
+  # some checks on the data
+  if (!is.null(data)) {
+    if (!is.data.frame(data)) {
+      stop("Error with 'data' argument: semtree currently only supports data frames.")
+    }
+  }
+  
   # TODO: change this throughout
   dataset <- data
 
@@ -132,16 +140,41 @@ semtree <- function(model, data = NULL, control = NULL, constraints = NULL,
     }
   }
 
+  # here we decide between four cases depending
+  # on whether min.N is given and/or min.bucket is given
   # this is a really dumb heuristic
   # please can someone replace this with something more useful
   # this based on (Bentler & Chou, 1987; see also Bollen, 1989)
+  
   if (is.null(control$min.N)) {
-    control$min.N <- 5 * npar(model)
+    
+    if (is.null(control$min.bucket)) {
+      # both values were not specified 
+      control$min.N <- max(20, 5 * npar(model))
+      control$min.bucket <- max(10, control$min.N / 2)
+    } else {
+      # only min.bucket was given, min.N was not specified
+      control$min.N <- control$min.bucket * 2
+    }
+  } else {
+    if (is.null(control$min.bucket)) {
+      # only min.N was given, min.bucket was not specified
+      control$min.bucket <- max(10, control$min.N / 2)     
+    } else {
+      # do nothing, both values were specified
+      if (control$min.bucket > control$min.N) {
+        warning("Min.bucket parameter should probably be smaller than min.N!")
+      }
+    }
+  }
+  
+  if (is.null(control$min.N)) {
+
   }
 
   # set min.bucket and min.N heuristically
   if (is.null(control$min.bucket)) {
-    control$min.bucket <- control$min.N / 2
+
   }
 
   if (control$method == "cv") {
