@@ -67,7 +67,8 @@ varimp <- function(forest,
       max.level = NA,
       eval.fun = eval.fun,
       method = method,
-      constraints = forest$constraints
+      constraints = forest$constraints,
+      loglik = forest$control$semtree.control$loglik
     ),
     SIMPLIFY = FALSE,
     USE.NAMES = TRUE,
@@ -84,13 +85,13 @@ varimp <- function(forest,
       try({
         x$ll.baseline
       })
-    })
+    }, simplify="matrix")
   result$importance <-
     t(sapply(temp, function(x) {
       try({
         x$total
       })
-    }))
+    }, simplify="matrix"))
   result$elapsed <- elapsed
   
   # completeley experimental, probably not a wise idea to use this
@@ -115,11 +116,19 @@ varimp <- function(forest,
     colnames(result$importance.level1) <- var.names
   }
   
-  if (dim(result$importance)[1] == 1) {
-    #result$importance<-t(result$importance)
-    result$ll.baselines <-
-      t(t(result$ll.baselines)) # TODO: this is stupid, should be as.matrix?!
-  }
+  # at this stage, result$importance should be a k x p matrix
+  # with k being the number of trees and p being the number
+  # of predictors
+  # result$ll.baselines is a vector of length k
+ 
+  # in case, the result is only from a single predictor, 
+  # then transpose results accordingly such that is k x p 
+  if (length(var.names) == 1) {
+    result$importance<-matrix(result$importance, ncol=1)
+  
+   # result$ll.baselines <-
+  #    matrix(result$ll.baselines, ncol=1) 
+   }
   
   colnames(result$importance) <- var.names
   result$var.names <- var.names
